@@ -75,7 +75,7 @@
 ################################################################################
 
 diffrisk_analysis <- function(dframe, vars_response, vars_stressor, response_levels = NULL,
-                              stressor_levels = NULL, subpops = NULL, siteID = "siteID", weight = "weight",
+                              stressor_levels = NULL, subpops = NULL, siteID = NULL, weight = "weight",
                               xcoord = NULL, ycoord = NULL, stratumID = NULL, clusterID = NULL,
                               weight1 = NULL, xcoord1 = NULL, ycoord1 = NULL, sizeweight = FALSE,
                               sweight = NULL, sweight1 = NULL, fpc = NULL, popsize = NULL,
@@ -129,6 +129,13 @@ diffrisk_analysis <- function(dframe, vars_response, vars_stressor, response_lev
 
   dframe <- droplevels(dframe)
 
+  # If no siteID is provided, set one that assumes each row is a unique site
+
+  if (is.null(siteID)) {
+    siteID <- "siteID"
+    dframe$siteID <- paste("site", seq_len(nrow(dframe)), sep = "-")
+  }
+
   # Ensure that the dframe data frame contains the site ID variable
 
   if (!(siteID %in% names(dframe))) {
